@@ -29,7 +29,7 @@ class Plan(models.Model):
     trial_days = models.IntegerField(default=3)
 
     # Payment details
-    price = models.DecimalField(max_digits=10, decimal_places=2, unique=True)
+    price = models.DecimalField(max_digits=10, decimal_places=2)
     recurring_interval = models.CharField(
             choices=RECURRING_INTERVALS,
             max_length=255)
@@ -109,6 +109,13 @@ class Subscription(models.Model):
                 stripe.PaymentMethod.attach(pm.id, customer=obj.customer_id)
                 kwargs['default_payment_method'] = pm.id
 
+                if pm.billing_details and pm.billing_details.email:
+                    user.email = pm.billing_details.email
+                    user.save()
+
+                    if customer.email != user.email:
+                        stripe.Customer.modify(customer.id, email=user.email)
+
             sub = stripe.Subscription.create(**kwargs)
             obj.subscription_id = sub.id
 
@@ -129,17 +136,16 @@ class Subscription(models.Model):
         if not plan.deep_link:
             return None
 
-        parts = [plan.deep_link]
+        link = plan.deep_link
 
-        if self.quiz:
-            parts.append(self.quiz)
+        for p in [self.quiz, 'subscription_id=%s' % self.subscription_id]:
+            if not p:
+                continue
 
-        glue = '?'
+            glue = '&' if '?' in link else '?'
+            link = glue.join([link, p])
 
-        if glue in plan.deep_link:
-            glue = '&'
-
-        return glue.join(parts)
+        return link
 
     def __str__(self):
         return "<Subscription: {}>".format(self.subscription_id)
